// Vertex shader
//
// gl_ModelViewProjectionMatrix - aktualni matice prevodu do clipping coordinate system
// gl_ModelViewMatrix - eye coordinates
// gl_NormalMatrix - transformace normalovych vektoru do eye coordinates
// gl_Normal
// gl_Vertex

#version 400

uniform vec3 lightPosition;

uniform mat4 modelViewMatrix;
uniform mat3 normalMatrix;
uniform mat4 MVP;

//attribute vec3 vertexPosition; //#version 120
layout(location=0) in vec3 vertexPosition;
layout(location=1) in vec3 vertexNormal;
layout(location=2) in vec2 vertexTexCoord;

out float lightIntensity;
out vec2 MCPosition;
out vec2 texCoord;
out float diff;

const float diffuseContribution = 0.7;
const float specularContribution = 1.0 - diffuseContribution;

void main()
{
	vec3 ecPosition = vec3(modelViewMatrix * vec4(vertexPosition, 1.0));
	vec3 lightVec = normalize(lightPosition - ecPosition);
	vec3 tNorm = normalize(normalMatrix * (-vertexNormal));
	vec3 viewVec = normalize(-ecPosition);
	vec3 reflectVec = reflect(-lightVec, tNorm);

	float diffuse = max(dot(tNorm, lightVec), 0.0);
	diff= diffuse;

	float specular = 0.0;
	if(diffuse > 0.0)
	{
		specular = max(dot(viewVec, reflectVec), 0.0);
		specular = pow(specular, 16.0);
	}

	lightIntensity = diffuse * diffuseContribution + specular * specularContribution;
	MCPosition = vertexPosition.xy;
	texCoord = vertexTexCoord;

	gl_Position= MVP * vec4(vertexPosition, 1.0);
}